
use serde::*;

#[derive(Debug, Serialize, Deserialize, Clone)]
pub struct Server {
    name: Option<String>,
    domain: Option<String>,
    info: Option<String>,
    jurisdiction: Option<String>,
    tos: Option<String>,
    privacy: Option<String>,
    open: bool,
    remarks: Option<String>,
    antifeature: Option<String>,
    reg_method: Option<String>,
    reg_link: Option<String>,
    software: Option<String>,
    version: Option<String>,
    recaptcha: bool,
    email: bool
}

#[tauri::command]
pub async fn list_servers() -> Result<Vec<Server>, String> {
    let req = reqwest::get("https://joinmatrix.org/servers.json").await;
    if req.is_err() {
        return Err(req.unwrap_err().to_string());
    }
    let req = req.unwrap().text().await;
    if req.is_err() {
        return Err(req.unwrap_err().to_string());
    }
    let req = req.unwrap();

    let data = serde_json::from_str::<Vec<Server>>(req.as_str());
    if data.is_err() {
        return Err(data.unwrap_err().to_string());
    }

    Ok(data.unwrap())
}