
/**
 * Set CSS variable
 * 
 * @param name Name of the variable
 * @param val  Value to be set
 */
export function setCSSVariable(name: string, val: string | number): void {

    if (typeof val == 'number') val = `${val}px`;
    if (!name.startsWith('--')) name = `--${name}`;

    // @ts-ignore
    document.querySelector(':root').style.setProperty(name, val);
}

/**
 * Get the CSS variable's contents
 * 
 * @param name Name of the variable
 * @returns    Its current value
 */
export function getCSSVariable(name: string): string {
    if (!name.startsWith('--')) name = `--${name}`;

    // @ts-ignore
    return document.querySelector(':root').style.getPropertyValue(name);
}

/**
 * Set CSS variable and after n milliseconds revert it back
 * 
 * @param name    Name of the variable
 * @param val     Value to be set
 * @param timeout Time for which the variable should be set
 */
export function setCSSVariableFor(name: string, val: string | number, timeout: number): void {
    const old = getCSSVariable(name);
    setCSSVariable(name, val);
    setTimeout(() => setCSSVariable(name, old), timeout);
}